@@ -51,7 +51,7 @@ def __fs__(X, fi, X_names = None, N = 30, display = True):
     and '3' meaning class 'C' make no sense.
     '''
 
-    if display:        
+    if display:
         plot_feature_importance(fi, X_names, 'feature-wise coefs/values', xtick_angle=0)
 
     idx = (np.argsort(fi)[-N:])[::-1]
@@ -184,11 +184,12 @@ def alasso_fs(X, y, X_names=None, N = 30, LAMBDA = 0.1, flavor = 2, \
     else: # flavor 3
         coef_, R2 = alasso_v3(X, y, LAMBDA=LAMBDA)
 
-    eps = 1e-9 # epsilon - non-zero coef cut threshold
+    eps = 0 # 1e-9 # epsilon - non-zero coef cut threshold
     NZ = np.count_nonzero(coef_ > eps)
     
     if verbose:
         print('R2 = ', round(R2,3) ) # R2 - the coefficient of determination 
+        # print(coef_)
         print('Non-zero feature coefficients (eps = %2g'%eps + '):', NZ)
     
     if N is None or N <=0 or N > NZ:
