@@ -61,7 +61,7 @@ def x_binning(X, X_names = None, target_dim = 0.1, flavor = 'max', display = Fal
     n = X.shape[1]
     if target_dim < 1:
         target_dim = int(target_dim * n)
-    if target_dim >= 1:
+    elif target_dim >= 1:
         target_dim = n
         return X, X_names
 
@@ -79,7 +79,7 @@ def x_binning(X, X_names = None, target_dim = 0.1, flavor = 'max', display = Fal
         else: # sum / rect /mean
             NCol = a.sum(axis = 1)
         NX.append( NCol )
-        
+    
     NX = np.array(NX).T
 
     if display:
